[Libreoffice-commits] core.git: 2 commits - config_host.mk.in configure.ac desktop/Pagein_common.mk instsetoo_native/util Repository.mk RepositoryModule_host.mk solenv/bin solenv/gbuild

Matúš Kukan matus.kukan at gmail.com
Tue Apr 16 02:51:29 PDT 2013


 Repository.mk                                  |    2 +-
 RepositoryModule_host.mk                       |    2 +-
 config_host.mk.in                              |    1 -
 configure.ac                                   |    2 --
 desktop/Pagein_common.mk                       |    2 +-
 instsetoo_native/util/openoffice.lst.in        |    4 ++--
 solenv/bin/modules/installer/profiles.pm       |    4 ++--
 solenv/gbuild/extensions/pre_MergedLibsList.mk |   17 ++++++++---------
 8 files changed, 15 insertions(+), 19 deletions(-)

New commits:
commit 75ece7acdc81d17ce26bab966e57fbca7406bf52
Author: Matúš Kukan <matus.kukan at gmail.com>
Date:   Tue Apr 16 11:47:34 2013 +0200

    do not merge public ure libraries
    
    No more need for URELIBS, depend only on MERGELIBS.
    
    Change-Id: I5a93031116c26bbbe375e9c467e7b427487ec18b

diff --git a/Repository.mk b/Repository.mk
index 15c3481..26556af 100644
--- a/Repository.mk
+++ b/Repository.mk
@@ -431,7 +431,7 @@ $(eval $(call gb_Helper_register_libraries_for_install,PLAINLIBS_URE,URE, \
 	$(if $(SOLAR_JAVA),sunjavaplugin) \
 	unoidl \
 	unsafe_uno \
-	$(if $(URELIBS),urelibs) \
+	$(if $(MERGELIBS),urelibs) \
 	xmlreader \
 	$(if $(filter MSC,$(COM)),$(if $(filter INTEL,$(CPUNAME)),msci,mscx),gcc3)_uno \
 ))
diff --git a/RepositoryModule_host.mk b/RepositoryModule_host.mk
index 3b425d0..a8bf87d 100644
--- a/RepositoryModule_host.mk
+++ b/RepositoryModule_host.mk
@@ -240,7 +240,7 @@ $(eval $(call gb_Module_add_moduledirs,libreoffice,\
 ifneq ($(MERGELIBS),)
 $(eval $(call gb_Module_add_targets,libreoffice,\
 	Library_merged \
-	$(if $(URELIBS),Library_urelibs) \
+	Library_urelibs \
 ))
 endif
 
diff --git a/config_host.mk.in b/config_host.mk.in
index 4256fa7..fcfccd3 100644
--- a/config_host.mk.in
+++ b/config_host.mk.in
@@ -536,7 +536,6 @@ export TYPO_EXTENSION_PACK=@TYPO_EXTENSION_PACK@
 export UNIXWRAPPERNAME=@UNIXWRAPPERNAME@
 export UNOWINREG_DLL=@UNOWINREG_DLL@
 export UPD=@UPD@
-export URELIBS=@URELIBS@
 export USE_FT_EMBOLDEN=@USE_FT_EMBOLDEN@
 export USE_XINERAMA=@USE_XINERAMA@
 export use_shl_version=@use_shl_version@
diff --git a/configure.ac b/configure.ac
index 64e574e7..e34e965 100644
--- a/configure.ac
+++ b/configure.ac
@@ -11723,7 +11723,6 @@ if test -n "$enable_mergelibs" -a "$enable_mergelibs" != "no"; then
     fi
     if test "$enable_mergelibs" = "all"; then
         MERGELIBS="ALL"
-        URELIBS="TRUE"
     else
         MERGELIBS="CORE"
     fi
@@ -11732,7 +11731,6 @@ else
     AC_MSG_RESULT([no])
 fi
 AC_SUBST([MERGELIBS])
-AC_SUBST([URELIBS])
 
 # ===================================================================
 # Create hardlinks on deliver instead of copying for smaller size and speed up
diff --git a/desktop/Pagein_common.mk b/desktop/Pagein_common.mk
index f13ac72..d6ec2f9 100644
--- a/desktop/Pagein_common.mk
+++ b/desktop/Pagein_common.mk
@@ -30,7 +30,7 @@ $(eval $(call gb_Pagein_Pagein,common))
 # sorted in approx. reverse load order (ld.so.1)
 $(eval $(call gb_Pagein_add_objects,common,\
     $(if $(MERGELIBS),merged) \
-    $(if $(URELIBS),urelibs) \
+    $(if $(MERGELIBS),urelibs) \
     i18nlangtag \
     $(if $(findstring YES,$(SYSTEM_ICU)),,\
         icui18n \
diff --git a/solenv/gbuild/extensions/pre_MergedLibsList.mk b/solenv/gbuild/extensions/pre_MergedLibsList.mk
index a799aaa..4bbb22e 100644
--- a/solenv/gbuild/extensions/pre_MergedLibsList.mk
+++ b/solenv/gbuild/extensions/pre_MergedLibsList.mk
@@ -179,21 +179,20 @@ gb_MERGEDLIBS := \
 	xstor \
 	$(if $(filter ALL,$(MERGELIBS)),$(gb_EXTRAMERGEDLIBS))
 
-ifneq (,$(URELIBS))
 gb_URELIBS := \
-	cppu \
-	cppuhelper \
 	$(if $(filter TRUE,$(SOLAR_JAVA)),jvmaccess) \
 	$(if $(filter TRUE,$(SOLAR_JAVA)),jvmfwk) \
-	purpenvhelper \
 	reg \
-	sal \
-	salhelper \
 	store \
 	unoidl \
-	xmlreader
-
-endif
+	xmlreader \
+	$(if $(filter ALL,$(MERGELIBS)), \
+		cppu \
+		cppuhelper \
+		purpenvhelper \
+		sal \
+		salhelper \
+	)
 
 endif
 
commit fdb6b39d682372ece754afee2d574ab31552f36b
Author: Matúš Kukan <matus.kukan at gmail.com>
Date:   Tue Apr 16 11:31:58 2013 +0200

    fix installing for --enable-mergelibs
    
    Use gid_File_Lib_Oox instead of auto_File_Lib_vcl which is not defined
    in that case.
    No idea what the code is about though.
    
    Change-Id: I675268a3490dd1421ecf1a82ede0db527d176744

diff --git a/instsetoo_native/util/openoffice.lst.in b/instsetoo_native/util/openoffice.lst.in
index 60e402f..61d295b 100644
--- a/instsetoo_native/util/openoffice.lst.in
+++ b/instsetoo_native/util/openoffice.lst.in
@@ -64,7 +64,7 @@ LibreOffice
             PACKAGEVERSION @LIBO_VERSION_MAJOR at .@LIBO_VERSION_MINOR at .@LIBO_VERSION_MICRO at .@LIBO_VERSION_PATCH@@LIBO_VERSION_SUFFIX@
             PACKAGEREVISION {buildid}
             LICENSENAME LGPL
-            GLOBALFILEGID auto_File_Lib_vcl
+            GLOBALFILEGID gid_File_Lib_Oox
             GLOBALPATCHFILEGID gid_File_Txt_Patchfiles
             SPELLCHECKERFILE spellchecker_selection.txt
             OOODOWNLOADNAME 1
@@ -120,7 +120,7 @@ LibreOffice_Dev
             PACKAGEVERSION @LIBO_VERSION_MAJOR at .@LIBO_VERSION_MINOR at .@LIBO_VERSION_MICRO at .@LIBO_VERSION_PATCH@@LIBO_VERSION_SUFFIX@
             PACKAGEREVISION {buildid}
             LICENSENAME LGPL
-            GLOBALFILEGID auto_File_Lib_vcl
+            GLOBALFILEGID gid_File_Lib_Oox
             GLOBALPATCHFILEGID gid_File_Txt_Patchfiles
             SPELLCHECKERFILE spellchecker_selection.txt
             OOODOWNLOADNAME 1
diff --git a/solenv/bin/modules/installer/profiles.pm b/solenv/bin/modules/installer/profiles.pm
index b83b696..5dadf80 100644
--- a/solenv/bin/modules/installer/profiles.pm
+++ b/solenv/bin/modules/installer/profiles.pm
@@ -84,9 +84,9 @@ sub add_profile_into_filelist
 
     my %profile = ();
 
     # Taking the base data from the "auto_File_Lib_vcl"
 
-    my $vclgid = "auto_File_Lib_vcl";
+    my $vclgid = "gid_File_Lib_Oox";
     if ( $allvariables->{'GLOBALFILEGID'} ) { $vclgid = $allvariables->{'GLOBALFILEGID'}; }
     my ($vclfile) = grep {$_->{gid} eq $vclgid} @{$filesarrayref};
     if (! defined $vclfile) {
@@ -84,9 +84,9 @@ sub add_profile_into_filelist
     my %profile = ();
 
-    # Taking the base data from the "auto_File_Lib_vcl"
+    # Taking the base data from the "gid_File_Lib_Oox"
 


More information about the Libreoffice-commits mailing list